@@ -14,6 +14,11 @@ import aws_cdk.aws_lambda
 import aws_cdk.aws_logs
 import aws_cdk.core
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-logs-destinations", "1.33.0", __name__[0:-6], "aws-logs-destinations@1.33.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
